export default {
  title: 'Ad',

  componentProps: [
    {
      name: 'type',
      type: [
        `'cube'`,
        `'supercube'`,
        `'leaderboard'`,
      ],
      description: 'The type of ad to display',
      default: `'supercube'`,
    },
    {
      name: 'observationThreshold',
      type: 'number',
      description: 'How long the ad space must be observed before it loads (in ms)',
      default: '500',
    },
    {
      name: 'rootMargin',
      type: 'string',
      description: 'How close a user needs to get to the ad space before the observaton starts',
      default: `'700px'`,
    },
  ],

  cssProps: [
    {
      name: 'root',
      globalClass: 'PibAd-root',
      description: 'Styles applied to root element that will have an ad mounted in it',
    },
    {
      name: 'container',
      globalClass: 'PibAd-container',
      description: 'Styles applied to container div',
    },
    {
      name: 'disclaimer',
      globalClass: 'PibAd-disclaimer',
      description: 'Styles applied to "Advertisement" disclaimer text',
    },
  ],

  examples: [
    {
      code: `

<Ad />

`,
    },
    {
      name: 'Other Ad Types',
      description: 'By default the "supercube" type is used for ads. You can also use the "cube" and "leaderboard" designation. Sometimes supercubes come through as cubes. That\'s okay.',
      code: `
<div>
  <Ad type="cube"/>
  <hr />
  <Ad type="leaderboard"/>
</div>`,
    },
    {
      name: 'Observation Threshold',
      description: 'By default, the space for an ad must be observed for 0.01 seconds before the ad is mounted on to the page. You can change this threshold by supplying an observationThreshold in milliseconds. You can also set it to a falsy value to disable this feature and have it mount on page load. Notice the first ad will take longer to load than the others, but the second one will likely already be loaded by the time you read this.',
      code: `
<div>
  <Ad observationThreshold={5000} />
  <hr />
  <Ad observationThreshold={null} />
</div>`,
    },
  ],
};
