import { useMemo } from 'react';
import uniq from 'lodash/uniq';
import assign from 'lodash/assign';
import JsxStyle from 'styled-jsx/style';
import postcss from 'postcss';

export default (stylesheet, overrideClasses) => {
  let stylesheetNamespace, styles, type;

  // type = resolve
  if (stylesheet.className) {
    type = 'resolve';
    stylesheetNamespace = stylesheet.className;
    styles = stylesheet.styles.props.children;
  }

  // type = scoped
  if (stylesheet.__hash) {
    type = 'scoped';
    stylesheetNamespace = `jsx-${stylesheet.__hash}`;
    styles = stylesheet.toString();
  }

  const classes = useMemo(() => {
    if (overrideClasses) {
      return overrideClasses;
    }

    return uniq(
      postcss
        .parse(styles).nodes
        .map(n => {
          if (!n.selector) {
            return null;
          }

          return n.selector.split(`.${stylesheetNamespace}`)[0].replace(/[.#]/g, '');
        })
        .filter(n => !!n)
    );
  }, [styles, stylesheetNamespace]);

  const classNameRef = useMemo(() => {
    const classNameRef = {};

    classes.forEach(c => {
      classNameRef[c] = c;
    });

    return classNameRef;
  }, [classes]);

  const restyled = useMemo(() => {
    return type === 'resolve' ?
      (<JsxStyle {...stylesheet.styles.props} namedClasses={classNameRef} />) :
      (<JsxStyle id={stylesheet.__hash} namedClasses={classNameRef}>{styles}</JsxStyle>);
  }, [styles, classNameRef]);

  const styledClasses = useMemo(() => {
    const styledClasses = {};

    classes.forEach(c => {
      styledClasses[c] = restyled.props.namedClasses[c] + ' ' + stylesheetNamespace;
    });

    return styledClasses;
  }, [classes, restyled, stylesheetNamespace]);

  return assign({ '__hash': stylesheetNamespace }, styledClasses);
};
