import { Element } from 'react-scroll';
import classnames from 'classnames';

import TD from './TD';
import stylesheet from './styles.module.scss';

import useStyledClasses from './hooks/useStyledClasses';

const Table = (props) => {
  const { name, colors, reference, minor, noCSS } = props;
  const classes = useStyledClasses(stylesheet);

  if (Array.isArray(colors)) {
    return (
      <div className='color-table'>
        <Element name={name} />
        <h2 className={classnames({ minor })}>{name} (<code>{reference}</code>)</h2>
        <table className='ramp'>
          <tbody>
            {colors.map((c, idx) =>
              <tr key={c + idx}>
                <TD className={classes.data} value={c}>
                  <span className='swatch' style={{ backgroundColor: c }} />
                </TD>
              </tr>
            )}
          </tbody>
        </table>
        <style jsx>{stylesheet}</style>
      </div>
    );
  } else {
    return (
      <div className='color-table'>
        <Element name={name} />
        <h2>{name} (<code>{reference}</code>)</h2>
        <table>
          <thead>
            <tr>
              <th>JavaScript</th>

              {!noCSS &&
                <th>SCSS</th>
              }

              <th>Value</th>
            </tr>
          </thead>
          <tbody>
            {Object.keys(colors).map(k => {
              if (Array.isArray(colors[k]) || typeof colors[k] === 'object') {
                return null;
              } else {
                return (
                  <tr key={k}>
                    <TD className={classes.data}>{k}</TD>

                    {!noCSS &&
                    <TD className={classes.data}>{`$${k.toLowerCase().replace(/_/g, '-')}`}</TD>
                    }

                    <TD className={classes.data} value={colors[k]}>
                      <span className='swatch' style={{ backgroundColor: colors[k] }} />
                      <span>{colors[k]}</span>
                    </TD>
                  </tr>
                );
              }
            })}
          </tbody>
        </table>
        <style jsx>{stylesheet}</style>
      </div>
    );
  }
};

Table.defaultProps = {
  noCSS: false,
  minor: false,
};

export default Table;
