import { useState, useCallback, useEffect } from 'react';

import { Element } from 'react-scroll';
import {
  LiveProvider,
  LiveEditor,
  LiveError,
  LivePreview
} from 'react-live';

import theme from 'Components/common/themes/a11y-dark';

import ActionBar from './ActionBar';

import stylesheet from './styles.module.scss';

const Sandbox = props => {
  const { scope, example } = props;
  const { code: defaultCode, name, description } = example;
  const [showError, setShowError] = useState(false);
  const [code, setCode] = useState(defaultCode);
  const resetCode = useCallback(() => {
    setCode(defaultCode);
  }, [defaultCode]);

  useEffect(() => {
    resetCode();
  }, [defaultCode]);

  return (
    <LiveProvider code={code} scope={scope} theme={theme}>
      <div className='sandbox'>
        <Element name={name} />
        <h3>{name}</h3>
        <p>{description}</p>
        <div className='live-example'>
          <LivePreview />
        </div>

        <div className='code-block'>
          <ActionBar
            code={code}
            resetCode={resetCode}
            setShowError={setShowError}
          />
          <LiveEditor
            className='live-editor'
            value={code}
            onValueChange={code => setCode(code)}
          />
          {showError &&
            <div className='error-block'>
              <LiveError />
            </div>
          }
        </div>
      </div>
      <style jsx>{stylesheet}</style>
    </LiveProvider>
  );
};

export default Sandbox;
